@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2019, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -9,17 +7,21 @@
 
 from cclib.parser.utils import find_package
 
+import numpy as np
+
 _found_psi4 = find_package("psi4")
 if _found_psi4:
     from psi4.core import Molecule
 
 
-def _check_psi4(found_psi4):
+def _check_psi4(found_psi4: bool) -> None:
     if not found_psi4:
         raise ImportError("You must install `psi4` to use this function")
 
 
-def makepsi4(atomcoords, atomnos, charge=0, mult=1):
+def makepsi4(
+    atomcoords: np.ndarray, atomnos: np.ndarray, charge: int = 0, mult: int = 1
+) -> "psi4.core.Molecule":
     """Create a Psi4 Molecule."""
     _check_psi4(_found_psi4)
     return Molecule.from_arrays(
