@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2020, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
 
 """Bridge for using cclib data in PyQuante (http://pyquante.sourceforge.net)."""
 
-import numpy
 from cclib.parser.utils import find_package
 
+import numpy
+
 
 class MissingAttributeError(Exception):
     pass
@@ -44,10 +43,7 @@ def makepyquante(data):
     moldesc = numpy.insert(data.atomcoords[-1], 0, data.atomnos, 1).tolist()
 
     return molecule(
-        [tuple(x) for x in moldesc],
-        units="Angstroms",
-        charge=data.charge,
-        multiplicity=data.mult,
+        [tuple(x) for x in moldesc], units="Angstroms", charge=data.charge, multiplicity=data.mult
     )
 
 
