@@ -1,13 +1,12 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2019, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
 
 """Bridge for using cclib data in PySCF (https://github.com/pyscf/pyscf)."""
 
-from cclib.parser.utils import find_package, PeriodicTable, convertor
+from cclib.parser.utils import PeriodicTable, convertor, find_package
+
 import numpy as np
 
 l_sym2num = {"S": 0, "P": 1, "D": 2, "F": 3, "G": 4}
@@ -16,6 +15,7 @@ l_sym2num = {"S": 0, "P": 1, "D": 2, "F": 3, "G": 4}
 class MissingAttributeError(Exception):
     pass
 
+
 _found_pyscf = find_package("pyscf")
 if _found_pyscf:
     from pyscf import gto
@@ -38,20 +38,16 @@ def makepyscf(data, charge=0, mult=1):
             f"Could not create pyscf molecule due to missing attribute: {missing}"
         )
     mol = gto.Mole(
-        atom=[
-            [f"{data.atomnos[i]}", data.atomcoords[-1][i]] for i in range(data.natom)
-        ],
+        atom=[[f"{data.atomnos[i]}", data.atomcoords[-1][i]] for i in range(data.natom)],
         unit="Angstrom",
         charge=charge,
-        multiplicity=mult
+        multiplicity=mult,
     )
     inputattr = data.__dict__
     pt = PeriodicTable()
     if "gbasis" in inputattr:
         basis = {}  # object for internal PySCF format
-        uatoms, uatoms_idx = np.unique(
-            data.atomnos, return_index=True
-        )  # find unique atoms
+        uatoms, uatoms_idx = np.unique(data.atomnos, return_index=True)  # find unique atoms
         for idx, i in enumerate(uatoms_idx):
             curr_atom_basis = data.gbasis[i]
             for jdx, j in enumerate(curr_atom_basis):
@@ -67,7 +63,8 @@ def makepyscf(data, charge=0, mult=1):
         mol.cart = True
     return mol
 
-def makepyscf_mos(ccdata,mol):
+
+def makepyscf_mos(ccdata, mol):
     """
     Returns pyscf formatted MO properties from a cclib object.
     Parameters
@@ -91,29 +88,30 @@ def makepyscf_mos(ccdata,mol):
     inputattrs = ccdata.__dict__
     if "mocoeffs" in inputattrs:
         mol.build()
-        s = mol.intor('int1e_ovlp')
+        s = mol.intor("int1e_ovlp")
         if np.shape(ccdata.mocoeffs)[0] == 1:
-            mo_coeffs = np.einsum('i,ij->ij', np.sqrt(1/s.diagonal()), ccdata.mocoeffs[0].T)
+            mo_coeffs = np.einsum("i,ij->ij", np.sqrt(1 / s.diagonal()), ccdata.mocoeffs[0].T)
             mo_occ = np.zeros(ccdata.nmo)
-            mo_occ[:ccdata.homos[0]+1] = 2
-            mo_energies = convertor(np.array(ccdata.moenergies),"eV","hartree")
-            if hasattr(ccdata, 'mosyms'):
+            mo_occ[: ccdata.homos[0] + 1] = 2
+            mo_energies = convertor(np.array(ccdata.moenergies), "eV", "hartree")
+            if hasattr(ccdata, "mosyms"):
                 mo_syms = ccdata.mosyms
             else:
-                mo_syms = np.full_like(ccdata.moenergies, 'A', dtype=str)
+                mo_syms = np.full_like(ccdata.moenergies, "A", dtype=str)
 
         elif np.shape(ccdata.mocoeffs)[0] == 2:
-            mo_coeff_a = np.einsum('i,ij->ij', np.sqrt(1/s.diagonal()), ccdata.mocoeffs[0].T)
-            mo_coeff_b = np.einsum('i,ij->ij', np.sqrt(1/s.diagonal()), ccdata.mocoeffs[1].T)
-            mo_occ = np.zeros((2,ccdata.nmo))
-            mo_occ[0,:ccdata.homos[0]+1] = 1
-            mo_occ[1,:ccdata.homos[1]+1] = 1
-            mo_coeffs = np.array([mo_coeff_a,mo_coeff_b])
-            mo_energies = convertor(np.array(ccdata.moenergies),"eV","hartree")
-            if hasattr(ccdata, 'mosyms'):
+            mo_coeff_a = np.einsum("i,ij->ij", np.sqrt(1 / s.diagonal()), ccdata.mocoeffs[0].T)
+            mo_coeff_b = np.einsum("i,ij->ij", np.sqrt(1 / s.diagonal()), ccdata.mocoeffs[1].T)
+            mo_occ = np.zeros((2, ccdata.nmo))
+            mo_occ[0, : ccdata.homos[0] + 1] = 1
+            mo_occ[1, : ccdata.homos[1] + 1] = 1
+            mo_coeffs = np.array([mo_coeff_a, mo_coeff_b])
+            mo_energies = convertor(np.array(ccdata.moenergies), "eV", "hartree")
+            if hasattr(ccdata, "mosyms"):
                 mo_syms = ccdata.mosyms
             else:
-                mo_syms = np.full_like(ccdata.moenergies, 'A', dtype=str)
+                mo_syms = np.full_like(ccdata.moenergies, "A", dtype=str)
     return mo_coeffs, mo_occ, mo_syms, mo_energies
 
+
 del find_package
