@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -8,14 +6,22 @@
 """A writer for XYZ (Cartesian coordinate) files."""
 
 from cclib.io import filewriter
+from cclib.parser.data import ccData
 
 
 class XYZ(filewriter.Writer):
     """A writer for XYZ (Cartesian coordinate) files."""
 
-    def __init__(self, ccdata, splitfiles=False,
-                 firstgeom=False, lastgeom=False, allgeom=False,
-                 *args, **kwargs):
+    def __init__(
+        self,
+        ccdata: ccData,
+        splitfiles: bool = False,
+        firstgeom: bool = False,
+        lastgeom: bool = False,
+        allgeom: bool = False,
+        *args,
+        **kwargs,
+    ) -> None:
         """Initialize the XYZ writer object.
 
         Inputs:
@@ -27,7 +33,7 @@ class XYZ(filewriter.Writer):
         """
         super().__init__(ccdata, *args, **kwargs)
 
-        self.required_attrs = ('natom', 'atomcoords', 'atomnos')
+        self.required_attrs = ("natom", "atomcoords", "atomnos")
 
         self.do_firstgeom = firstgeom
         self.do_lastgeom = lastgeom
@@ -36,7 +42,7 @@ class XYZ(filewriter.Writer):
         self.natom = str(self.ccdata.natom)
         self.element_list = [self.pt.element[Z] for Z in self.ccdata.atomnos]
 
-    def generate_repr(self):
+    def generate_repr(self) -> str:
         """Generate the XYZ representation of the logfile data."""
 
         # Options for output (to a single file):
@@ -71,16 +77,19 @@ class XYZ(filewriter.Writer):
             xyzblock.append(self._xyz_from_ccdata(i))
 
         # Ensure an extra newline at the very end.
-        xyzblock.append('')
+        xyzblock.append("")
 
-        return '\n'.join(xyzblock)
+        return "\n".join(xyzblock)
 
-    def _xyz_from_ccdata(self, index):
+    def _xyz_from_ccdata(self, index: int) -> str:
         """Create an XYZ file of the geometry at the given index."""
 
         atomcoords = self.ccdata.atomcoords[index]
-        existing_comment = "" if "comments" not in self.ccdata.metadata \
+        existing_comment = (
+            ""
+            if "comments" not in self.ccdata.metadata
             else self.ccdata.metadata["comments"][index]
+        )
 
         # Create a comment derived from the filename and the index.
         if index == -1:
@@ -98,10 +107,10 @@ class XYZ(filewriter.Writer):
         else:
             comment = f"[{comment}]"
 
-        atom_template = '{:3s} {:15.10f} {:15.10f} {:15.10f}'
+        atom_template = "{:3s} {:15.10f} {:15.10f} {:15.10f}"
         block = []
         block.append(self.natom)
         block.append(comment)
         for element, (x, y, z) in zip(self.element_list, atomcoords):
             block.append(atom_template.format(element, x, y, z))
-        return '\n'.join(block)
+        return "\n".join(block)
