@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -9,33 +7,32 @@
 
 import random
 
-import numpy
-
 from cclib.method.fragments import FragmentAnalysis
 
+import numpy
+
 
 class CDA(FragmentAnalysis):
     """Charge Decomposition Analysis (CDA)"""
 
-    def __init__(self, *args):
+    def __init__(self, *args) -> None:
         super().__init__(logname="CDA", *args)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return a string representation of the object."""
         return f"CDA of {self.data}"
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return a representation of the object."""
         return f'CDA("{self.data}")'
 
-    def calculate(self, fragments, cupdate=0.05):
+    def calculate(self, fragments, cupdate: float = 0.05) -> bool:
         """Perform the charge decomposition analysis.
 
         Inputs:
             fragments - list of ccData data objects
         """
 
-
         retval = super().calculate(fragments, cupdate)
         if not retval:
             return False
@@ -63,7 +60,6 @@ class CDA(FragmentAnalysis):
         # Begin the actual method.
         step = 0
         for spin in range(len(self.mocoeffs)):
-
             size = len(self.mocoeffs[spin])
             homo = self.data.homos[spin]
 
@@ -92,27 +88,46 @@ class CDA(FragmentAnalysis):
             residuals.append(numpy.zeros(size, "d"))
 
             for i in range(self.data.homos[spin] + 1):
-
                 # Calculate donation for each MO.
                 for k in range(0, homoa + 1):
                     for n in range(offset + homob + 1, self.data.nbasis):
-                        donations[spin][i] += 2 * occs * self.mocoeffs[spin][i,k] \
-                                                * self.mocoeffs[spin][i,n] * fooverlaps[k][n]
+                        donations[spin][i] += (
+                            2
+                            * occs
+                            * self.mocoeffs[spin][i, k]
+                            * self.mocoeffs[spin][i, n]
+                            * fooverlaps[k][n]
+                        )
 
                 for l in range(offset, offset + homob + 1):
                     for m in range(homoa + 1, offset):
-                        bdonations[spin][i] += 2 * occs * self.mocoeffs[spin][i,l] \
-                                                * self.mocoeffs[spin][i,m] * fooverlaps[l][m]
+                        bdonations[spin][i] += (
+                            2
+                            * occs
+                            * self.mocoeffs[spin][i, l]
+                            * self.mocoeffs[spin][i, m]
+                            * fooverlaps[l][m]
+                        )
 
                 for k in range(0, homoa + 1):
-                    for m in range(offset, offset+homob + 1):
-                        repulsions[spin][i] += 2 * occs * self.mocoeffs[spin][i,k] \
-                                                * self.mocoeffs[spin][i, m] * fooverlaps[k][m]
+                    for m in range(offset, offset + homob + 1):
+                        repulsions[spin][i] += (
+                            2
+                            * occs
+                            * self.mocoeffs[spin][i, k]
+                            * self.mocoeffs[spin][i, m]
+                            * fooverlaps[k][m]
+                        )
 
                 for m in range(homoa + 1, offset):
                     for n in range(offset + homob + 1, self.data.nbasis):
-                        residuals[spin][i] += 2 * occs * self.mocoeffs[spin][i,m] \
-                                                * self.mocoeffs[spin][i, n] * fooverlaps[m][n]
+                        residuals[spin][i] += (
+                            2
+                            * occs
+                            * self.mocoeffs[spin][i, m]
+                            * self.mocoeffs[spin][i, n]
+                            * fooverlaps[m][n]
+                        )
 
                 step += 1
                 if self.progress and random.random() < cupdate:
