@@ -1,26 +1,23 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2020, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
 
 """Calculation of DDEC charges based on data parsed by cclib."""
 import copy
-import random
-import numpy
 import logging
 import math
 import os
+import random
 import sys
+from typing import List
 
 from cclib.method.calculationmethod import Method
 from cclib.method.stockholder import Stockholder
 from cclib.method.volume import electrondensity_spin
-from cclib.parser.utils import convertor
-from cclib.parser.utils import find_package
+from cclib.parser.utils import convertor, find_package
 
-from typing import List
+import numpy
 
 
 class MissingInputError(Exception):
@@ -48,24 +45,24 @@ class DDEC6(Stockholder):
         loglevel=logging.INFO,
         logname="Log",
     ):
-        """ Initialize DDEC6 object.
-            Inputs are:
-                data -- ccData object that describe target molecule.
-                volume -- Volume object that describe target Cartesian grid.
-                proatom_path -- path to proatom densities
-                (directory containing atoms.h5 in horton or c2_001_001_000_400_075.txt in chargemol)
-                convergence_level -- convergence level to use for conditioning densities in step 3
-                max_iteration -- maximum iteration to optimize phi in step 3-6
-            
-            Note:
-                Proatom densities are used in DDEC6 algorithm in a similar way to other stockholder
-                partitioning methods. They are used as references to appropriately partition the
-                total densities (which is the density stored in cube files). Proatom densities are
-                densities obtained for single atom or ion in a radial grid that originates from
-                the atom or ion.
-                In DDEC6 algorithm, stockholder partitioning is heavily modified to ensure that the
-                total densities that are partitioned resemble the proatom densities and to prevent
-                the numerical algorithm from failing to converge.
+        """Initialize DDEC6 object.
+        Inputs are:
+            data -- ccData object that describe target molecule.
+            volume -- Volume object that describe target Cartesian grid.
+            proatom_path -- path to proatom densities
+            (directory containing atoms.h5 in horton or c2_001_001_000_400_075.txt in chargemol)
+            convergence_level -- convergence level to use for conditioning densities in step 3
+            max_iteration -- maximum iteration to optimize phi in step 3-6
+
+        Note:
+            Proatom densities are used in DDEC6 algorithm in a similar way to other stockholder
+            partitioning methods. They are used as references to appropriately partition the
+            total densities (which is the density stored in cube files). Proatom densities are
+            densities obtained for single atom or ion in a radial grid that originates from
+            the atom or ion.
+            In DDEC6 algorithm, stockholder partitioning is heavily modified to ensure that the
+            total densities that are partitioned resemble the proatom densities and to prevent
+            the numerical algorithm from failing to converge.
         """
         super().__init__(data, volume, proatom_path, progress, loglevel, logname)
 
@@ -88,12 +85,15 @@ class DDEC6(Stockholder):
         super()._check_required_attributes()
 
     def _cartesian_dist(self, pt1, pt2):
-        """ Small utility function that calculates Euclidian distance between two points
-            pt1 and pt2 are numpy arrays representing a point in Cartesian coordinates. """
+        """Small utility function that calculates Euclidian distance between two points
+        pt1 and pt2 are numpy arrays representing a point in Cartesian coordinates."""
         return numpy.sqrt(numpy.dot(pt1 - pt2, pt1 - pt2))
 
     def _read_proatom(
-        self, directory, atom_num, charge  # type = str  # type = int  # type = float
+        self,
+        directory,
+        atom_num,
+        charge,  # type = str  # type = int  # type = float
     ):
         return super()._read_proatom(directory, atom_num, charge)
 
@@ -110,7 +110,6 @@ class DDEC6(Stockholder):
             f"Total charge density in the grid is {integrated_density}. If this does not match what is expected, using a finer grid may help."
         )
 
-
         # * STEP 1 *
         # Carry out step 1 of DDEC6 algorithm [Determining reference charge value]
         # Refer to equations 49-57 in doi: 10.1039/c6ra04656h
@@ -235,8 +234,8 @@ class DDEC6(Stockholder):
         self.fragcharges = numpy.array(self.data.atomnos - self.N_A[-1], dtype=float)
 
     def _check_kappa(self):
-        """ Return whether kappa needs to be updated or not based on Figure S4.2
-            of doi: 10.1039/c6ra04656h
+        """Return whether kappa needs to be updated or not based on Figure S4.2
+        of doi: 10.1039/c6ra04656h
         """
         if numpy.any([x if x < -1e-5 else 0 for x in self.N_A[-1]]):
             return True
@@ -252,11 +251,11 @@ class DDEC6(Stockholder):
             return self._update_kappa
 
     def calculate_reference_charges(self):
-        """ Calculate reference charges from proatom density and molecular density
-            [STEP 1 and 2]
-            
-            Function returns calculated reference charges, localized charges, and stockholder
-            charges.
+        """Calculate reference charges from proatom density and molecular density
+        [STEP 1 and 2]
+
+        Function returns calculated reference charges, localized charges, and stockholder
+        charges.
         """
         # Generator object to iterate over the grid
         ngridx, ngridy, ngridz = self.charge_density.data.shape
@@ -267,12 +266,7 @@ class DDEC6(Stockholder):
         self.closest_r_index = numpy.zeros(grid_shape, dtype=int)
 
         indices = numpy.asanyarray(
-            tuple(
-                (x, y, z)
-                for x in range(ngridx)
-                for y in range(ngridy)
-                for z in range(ngridz)
-            )
+            tuple((x, y, z) for x in range(ngridx) for y in range(ngridy) for z in range(ngridz))
         )
         coordinates = self.charge_density.coordinates(indices)
 
@@ -280,9 +274,10 @@ class DDEC6(Stockholder):
             # Distance of the grid from atom grid
             self.closest_r_index[atomi] = numpy.argmin(
                 numpy.abs(
-                    self.radial_grid_r[atomi][..., numpy.newaxis] - numpy.linalg.norm(self.data.atomcoords[-1][atomi] - coordinates, axis=1)
+                    self.radial_grid_r[atomi][..., numpy.newaxis]
+                    - numpy.linalg.norm(self.data.atomcoords[-1][atomi] - coordinates, axis=1)
                 ),
-                axis=0
+                axis=0,
             ).reshape((ngridx, ngridy, ngridz))
 
             # Equation 54 in doi: 10.1039/c6ra04656h
@@ -317,8 +312,8 @@ class DDEC6(Stockholder):
         return reference_charges, localizedcharges, stockholdercharges
 
     def condition_densities(self):
-        """ Calculate conditioned densities
-            [STEP 3]
+        """Calculate conditioned densities
+        [STEP 3]
         """
         # Generator object to iterate over the grid
         ngridx, ngridy, ngridz = self.charge_density.data.shape
@@ -327,9 +322,7 @@ class DDEC6(Stockholder):
 
         for atomi in range(self.data.natom):
             # rho_ref -- Equation 41 in doi: 10.1039/c6ra04656h
-            self._rho_ref += self.proatom_density[atomi][
-                self.closest_r_index[atomi]
-            ]
+            self._rho_ref += self.proatom_density[atomi][self.closest_r_index[atomi]]
 
         self._candidates_bigPhi = []
         self._candidates_phi = []
@@ -395,9 +388,7 @@ class DDEC6(Stockholder):
 
         # rho_cond -- equation 65 in doi: 10.1039/c6ra04656h
         for atomi in range(self.data.natom):
-            self.rho_cond.data += self._cond_density[atomi][
-                self.closest_r_index[atomi]
-            ]
+            self.rho_cond.data += self._cond_density[atomi][self.closest_r_index[atomi]]
 
         rho_cond_sqrt = numpy.sqrt(self.rho_cond.data)
 
@@ -405,9 +396,7 @@ class DDEC6(Stockholder):
             self.tau.append(numpy.zeros_like(self.proatom_density[atomi], dtype=float))
             # leftterm is the first spherical average term in equation 66.
             # <rho^cond_A(r_A) / sqrt(rho^cond(r))>
-            self._rho_cond_cartesian[atomi] = self._cond_density[atomi][
-                self.closest_r_index[atomi]
-            ]
+            self._rho_cond_cartesian[atomi] = self._cond_density[atomi][self.closest_r_index[atomi]]
             self._leftterm[atomi] = self._rho_cond_cartesian[atomi] / rho_cond_sqrt
             for radiusi in range(len(self.tau[atomi])):
                 grid_filter = self.closest_r_index[atomi] == radiusi
@@ -458,8 +447,8 @@ class DDEC6(Stockholder):
         return ya
 
     def _calculate_w_and_u(self):
-        """ Calculate weights placed on each integration grid point
-            [STEP 4-7]
+        """Calculate weights placed on each integration grid point
+        [STEP 4-7]
         """
         # From equation 67, w_A(r_A) = self._cond_density
         # From equation 8, W(r) = self.rho_cond for the rest of this function
@@ -531,11 +520,11 @@ class DDEC6(Stockholder):
         return N_A
 
     def reshape_G(self):
-        """ Calculate G_A(r_A) and reshape densities
-        
-            This is a quantity introduced in DDEC6 as a constraint preventing the tails from being
-            too diffuse.
-            [STEP 4-7]
+        """Calculate G_A(r_A) and reshape densities
+
+        This is a quantity introduced in DDEC6 as a constraint preventing the tails from being
+        too diffuse.
+        [STEP 4-7]
         """
         self._candidates_bigPhi = []
         self._candidates_phi = []
@@ -581,11 +570,11 @@ class DDEC6(Stockholder):
             self._g[atomi] = self._update_phiaii(self.rho_wavg[atomi], bigphiAII[atomi], atomi)[1]
 
     def calculate_H(self):
-        """ Calculate H_A(r_A)
-            
-            This is a quantity introduced in DDEC6 as a constraint preventing the tails from being
-            too contracted.
-            [STEP 4-7]
+        """Calculate H_A(r_A)
+
+        This is a quantity introduced in DDEC6 as a constraint preventing the tails from being
+        too contracted.
+        [STEP 4-7]
         """
         self._h = []
         for atomi in range(len(self._g)):
@@ -686,24 +675,20 @@ class DDEC6(Stockholder):
         )
 
         for atomi in range(self.data.natom):
-            self.rho_cond.data += self._cond_density[atomi][
-                self.closest_r_index[atomi]
-            ]
-            self._rho_cond_cartesian[atomi] = self._cond_density[atomi][
-                self.closest_r_index[atomi]
-            ]
+            self.rho_cond.data += self._cond_density[atomi][self.closest_r_index[atomi]]
+            self._rho_cond_cartesian[atomi] = self._cond_density[atomi][self.closest_r_index[atomi]]
 
     def _converge_phi(self, phiA, superscript, atomi):
-        """ Update phi until it is positive.
-            This is used in step 3 (for phi_A^I) and in steps 4-6 (for phi_A^II).
-            
-            --- Inputs ---
-            phiA            Either phi_A^I or phi_A^II
-            superscript     1 when calculating phi_I (STEP 3)
-                            2 when calculating phi_II (STEPS 4-6)
-            atomi           Index of target atom as in ccData object
-            
-            Refer to Equation S101, Figure S1 and S3 for an overview.
+        """Update phi until it is positive.
+        This is used in step 3 (for phi_A^I) and in steps 4-6 (for phi_A^II).
+
+        --- Inputs ---
+        phiA            Either phi_A^I or phi_A^II
+        superscript     1 when calculating phi_I (STEP 3)
+                        2 when calculating phi_II (STEPS 4-6)
+        atomi           Index of target atom as in ccData object
+
+        Refer to Equation S101, Figure S1 and S3 for an overview.
         """
         # Initial value of bigphi is zero (Equation S100)
         bigphiA = 0.0
@@ -712,7 +697,11 @@ class DDEC6(Stockholder):
         candidates_phi = [phiA]
         candidates_bigphi = [bigphiA]
 
+        it_max = 200
+        curr_it = 0
+
         while phiA <= 0:
+            curr_it += 1
             # Iterative algorithm until convergence
             # Refer to S101 in doi: 10.1039/c6ra04656h
             if superscript == 1:
@@ -736,19 +725,23 @@ class DDEC6(Stockholder):
             candidates_phi.append(phiA)
             candidates_bigphi.append(bigphiA)
 
+            if curr_it == it_max:
+                self.logger.info("Hit iteration max")
+                break
+
         return candidates_phi, candidates_bigphi
 
     def _parabolic_fit(self, pseudodensity, superscript, atomi):
-        """ Optimize phi using parabolic fitting.
-            This is used in step 3 (for phi_A^I) and in steps 4-6 (for phi_A^II).
-            
-            --- Inputs ---
-            phiA            Either phi_A^I or phi_A^II
-            superscript     1 when calculating phi_I (STEP 3)
-                            2 when calculating phi_II (STEPS 4-6)
-            atomi           Index of target atom as in ccData object
-            
-            Refer to Figure S1 and S3 for an overview.
+        """Optimize phi using parabolic fitting.
+        This is used in step 3 (for phi_A^I) and in steps 4-6 (for phi_A^II).
+
+        --- Inputs ---
+        phiA            Either phi_A^I or phi_A^II
+        superscript     1 when calculating phi_I (STEP 3)
+                        2 when calculating phi_II (STEPS 4-6)
+        atomi           Index of target atom as in ccData object
+
+        Refer to Figure S1 and S3 for an overview.
         """
         # Set update methods for phi_A^I or phi_A^II
         if superscript == 1:
@@ -842,7 +835,7 @@ class DDEC6(Stockholder):
                 # the first candidiate phi values are evaluated.
                 corphi = update(pseudodensity, corbigPhi, atomi)[0]
                 self._candidates_bigPhi[atomi] = numpy.array(
-                    [lowerbigPhi, midbigPhi, upperbigPhi, roots.max(), roots.min(), corbigPhi,],
+                    [lowerbigPhi, midbigPhi, upperbigPhi, roots.max(), roots.min(), corbigPhi],
                     dtype=float,
                 )
                 self._candidates_phi[atomi] = numpy.array(
