@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -9,17 +7,17 @@
 
 import logging
 
-import numpy
-
 from cclib.method.calculationmethod import Method
 
+import numpy
+
 
 class Electrons(Method):
     """A container for methods pertaining to electrons."""
 
     def __init__(self, data, progress=None, loglevel=logging.INFO, logname="Log"):
         super().__init__(data, progress, loglevel, logname)
-        self.required_attrs = ('atomnos','charge','coreelectrons','homos')
+        self.required_attrs = ("atomnos", "charge", "coreelectrons", "homos")
 
     def __str__(self):
         """Returns a string representation of the object."""
@@ -36,7 +34,7 @@ class Electrons(Method):
     def beta(self):
         """Number of beta electrons"""
         return self.data.homos[-1] + 1
-        
+
     def count(self, core=False):
         """Returns the electron count in system.
 
