@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2018, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -9,17 +7,17 @@
 
 import random
 
-import numpy
-
 from cclib.method.calculationmethod import Method
 from cclib.method.population import Population
 
+import numpy
+
 
 def func(x):
-    if x==1:
+    if x == 1:
         return 1
     else:
-        return x+func(x-1)
+        return x + func(x - 1)
 
 
 class OPA(Population):
@@ -48,29 +46,29 @@ class OPA(Population):
             atoms = []
             indices = []
 
-            name = names[0].split('_')[0]
+            name = names[0].split("_")[0]
             atoms.append(name)
             indices.append([0])
 
             for i in range(1, len(names)):
-                name = names[i].split('_')[0]
+                name = names[i].split("_")[0]
                 try:
                     index = atoms.index(name)
-                except ValueError: #not found in atom list
+                except ValueError:  # not found in atom list
                     atoms.append(name)
                     indices.append([i])
                 else:
                     indices[index].append(i)
 
         # Determine number of steps, and whether process involves beta orbitals.
-        nfrag = len(indices) #nfrag
+        nfrag = len(indices)  # nfrag
         nstep = func(nfrag - 1)
-        unrestricted = (len(self.data.mocoeffs) == 2)
+        unrestricted = len(self.data.mocoeffs) == 2
         alpha = len(self.data.mocoeffs[0])
         nbasis = self.data.nbasis
 
         self.logger.info("Creating attribute results: array[4]")
-        results= [ numpy.zeros([nfrag, nfrag, alpha], "d") ]
+        results = [numpy.zeros([nfrag, nfrag, alpha], "d")]
         if unrestricted:
             beta = len(self.data.mocoeffs[1])
             results.append(numpy.zeros([nfrag, nfrag, beta], "d"))
@@ -78,10 +76,10 @@ class OPA(Population):
 
         if hasattr(self.data, "aooverlaps"):
             overlap = self.data.aooverlaps
-        elif hasattr(self.data,"fooverlaps"):
+        elif hasattr(self.data, "fooverlaps"):
             overlap = self.data.fooverlaps
 
-        #intialize progress if available
+        # intialize progress if available
         if self.progress:
             self.progress.initialize(nstep)
 
@@ -90,35 +88,30 @@ class OPA(Population):
 
         preresults = []
         for spin in range(len(self.data.mocoeffs)):
-            two = numpy.array([2.0]*len(self.data.mocoeffs[spin]),"d")
-
+            two = numpy.array([2.0] * len(self.data.mocoeffs[spin]), "d")
 
             # OP_{AB,i} = \sum_{a in A} \sum_{b in B} 2 c_{ai} c_{bi} S_{ab}
 
-            for A in range(len(indices)-1):
-
-                for B in range(A+1, len(indices)):
-
-                    if self.progress: #usually only a handful of updates, so remove random part
+            for A in range(len(indices) - 1):
+                for B in range(A + 1, len(indices)):
+                    if self.progress:  # usually only a handful of updates, so remove random part
                         self.progress.update(step, "Overlap Population Analysis")
 
                     for a in indices[A]:
-
-                        ca = self.data.mocoeffs[spin][:,a]
+                        ca = self.data.mocoeffs[spin][:, a]
 
                         for b in indices[B]:
-
-                            cb = self.data.mocoeffs[spin][:,b]
-                            temp = ca * cb * two *overlap[a,b]
-                            results[spin][A,B] = numpy.add(results[spin][A,B],temp)
-                            results[spin][B,A] = numpy.add(results[spin][B,A],temp)
+                            cb = self.data.mocoeffs[spin][:, b]
+                            temp = ca * cb * two * overlap[a, b]
+                            results[spin][A, B] = numpy.add(results[spin][A, B], temp)
+                            results[spin][B, A] = numpy.add(results[spin][B, A], temp)
 
                     step += 1
 
-        temparray2 = numpy.swapaxes(results[0],1,2)
-        self.results = [ numpy.swapaxes(temparray2,0,1) ]
+        temparray2 = numpy.swapaxes(results[0], 1, 2)
+        self.results = [numpy.swapaxes(temparray2, 0, 1)]
         if unrestricted:
-            temparray2 = numpy.swapaxes(results[1],1,2)
+            temparray2 = numpy.swapaxes(results[1], 1, 2)
             self.results.append(numpy.swapaxes(temparray2, 0, 1))
 
         if self.progress:
