@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2020, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -13,20 +11,19 @@
 # https://github.com/ben-albrecht/cclib/blob/master/cclib/parser/mopacparser.py
 # Merged and modernized by Geoff Hutchison
 
-import re
 import math
+import re
+
+from cclib.parser import data, logfileparser, utils
 
 import numpy
 
-from cclib.parser import data
-from cclib.parser import logfileparser
-from cclib.parser import utils
-
 
 def symbol2int(symbol):
     t = utils.PeriodicTable()
     return t.number[symbol]
 
+
 class MOPAC(logfileparser.Logfile):
     """A MOPAC20XX output file."""
 
@@ -46,13 +43,13 @@ class MOPAC(logfileparser.Logfile):
         return label
 
     def before_parsing(self):
-        #TODO
+        # TODO
 
         # Defaults
         charge = 0
-        self.set_attribute('charge', charge)
+        self.set_attribute("charge", charge)
         mult = 1
-        self.set_attribute('mult', mult)
+        self.set_attribute("mult", mult)
 
         # Keep track of whether or not we're performing an
         # (un)restricted calculation.
@@ -64,20 +61,24 @@ class MOPAC(logfileparser.Logfile):
         self.geomdone = False
 
         # Compile the dashes-and-or-spaces-only regex.
-        self.re_dashes_and_spaces = re.compile(r'^[\s-]+$')
+        self.re_dashes_and_spaces = re.compile(r"^[\s-]+$")
 
-        self.star = ' * '
-        self.stars = ' *******************************************************************************'
+        self.star = " * "
+        self.stars = (
+            " *******************************************************************************"
+        )
 
-        self.spinstate = {'SINGLET': 1,
-                          'DOUBLET': 2,
-                          'TRIPLET': 3,
-                          'QUARTET': 4,
-                          'QUINTET': 5,
-                          'SEXTET': 6,
-                          'HEPTET': 7,
-                          'OCTET': 8,
-                          'NONET': 9}
+        self.spinstate = {
+            "SINGLET": 1,
+            "DOUBLET": 2,
+            "TRIPLET": 3,
+            "QUARTET": 4,
+            "QUINTET": 5,
+            "SEXTET": 6,
+            "HEPTET": 7,
+            "OCTET": 8,
+            "NONET": 9,
+        }
 
     def extract(self, inputfile, line):
         """Extract information from the file object inputfile."""
@@ -87,9 +88,7 @@ class MOPAC(logfileparser.Logfile):
             # Ignore the platorm information for now (the last character).
             self.metadata["package_version"] = line.split()[8][:-1]
             # Use the year as the legacy (short) package version.
-            self.skip_lines(
-                inputfile, ["Stewart Computational Chemistry", "s", "s", "s", "s"]
-            )
+            self.skip_lines(inputfile, ["Stewart Computational Chemistry", "s", "s", "s", "s"])
             self.metadata["legacy_package_version"] = next(inputfile).split()[1][5:]
 
         # Extract the atomic numbers and coordinates from the optimized geometry
@@ -111,16 +110,15 @@ class MOPAC(logfileparser.Logfile):
         #     2       O          5.89768035  *  -0.31706418  *   0.00917035  *
         # ... etc.
         if line.split() == ["NUMBER", "SYMBOL", "(ANGSTROMS)", "(ANGSTROMS)", "(ANGSTROMS)"]:
-
             self.updateprogress(inputfile, "Attributes", self.cupdate)
 
             self.inputcoords = []
             self.inputatoms = []
 
-            blankline = inputfile.next()
+            blankline = next(inputfile)
 
             atomcoords = []
-            line = inputfile.next()
+            line = next(inputfile)
             while len(line.split()) > 6:
                 # MOPAC Version 14.019L 64BITS suddenly appends this block with
                 # "CARTESIAN COORDINATES" block with no blank line.
@@ -130,27 +128,27 @@ class MOPAC(logfileparser.Logfile):
                 yc = float(tokens[4])
                 zc = float(tokens[6])
                 atomcoords.append([xc, yc, zc])
-                line = inputfile.next()
+                line = next(inputfile)
 
             self.inputcoords.append(atomcoords)
 
             if not hasattr(self, "natom"):
-                self.atomnos = numpy.array(self.inputatoms, 'i')
+                self.atomnos = numpy.array(self.inputatoms, "i")
                 self.natom = len(self.atomnos)
 
-        if 'CHARGE ON SYSTEM =' in line:
+        if "CHARGE ON SYSTEM =" in line:
             charge = int(line.split()[5])
-            self.set_attribute('charge', charge)
+            self.set_attribute("charge", charge)
 
-        if 'SPIN STATE DEFINED' in line:
+        if "SPIN STATE DEFINED" in line:
             # find the multiplicity from the line token (SINGLET, DOUBLET, TRIPLET, etc)
             mult = self.spinstate[line.split()[1]]
-            self.set_attribute('mult', mult)
+            self.set_attribute("mult", mult)
 
         # Read energy (in kcal/mol, converted to eV)
         #
         # FINAL HEAT OF FORMATION =       -333.88606 KCAL =   -1396.97927 KJ
-        if 'FINAL HEAT OF FORMATION =' in line:
+        if "FINAL HEAT OF FORMATION =" in line:
             if not hasattr(self, "scfenergies"):
                 self.scfenergies = []
             self.scfenergies.append(utils.convertor(utils.float(line.split()[5]), "kcal/mol", "eV"))
@@ -158,28 +156,28 @@ class MOPAC(logfileparser.Logfile):
         # Molecular mass parsing (units will be amu)
         #
         # MOLECULAR WEIGHT        ==        130.1890
-        if line[0:35] == '          MOLECULAR WEIGHT        =':
+        if line[0:35] == "          MOLECULAR WEIGHT        =":
             self.molmass = utils.float(line.split()[3])
 
-        #rotational constants
-        #Example:
+        # rotational constants
+        # Example:
         #          ROTATIONAL CONSTANTS IN CM(-1)
         #
         #          A =    0.01757641   B =    0.00739763   C =    0.00712013
         # could also read in moment of inertia, but this should just differ by a constant: rot cons= h/(8*Pi^2*I)
         # note that the last occurence of this in the thermochemistry section has reduced precision,
         # so we will want to use the 2nd to last instance
-        if line[0:40] == '          ROTATIONAL CONSTANTS IN CM(-1)':
-            blankline = inputfile.next()
-            rotinfo = inputfile.next()
-            if not hasattr(self, "rotcons"):
-                self.rotcons = []
+        if line[0:40] == "          ROTATIONAL CONSTANTS IN CM(-1)":
+            blankline = next(inputfile)
+            rotinfo = next(inputfile)
+            if not hasattr(self, "rotconsts"):
+                self.rotconsts = []
             broken = rotinfo.split()
             # leave the rotational constants in Hz
             a = float(broken[2])
             b = float(broken[5])
             c = float(broken[8])
-            self.rotcons.append([a, b, c])
+            self.rotconsts.append([a, b, c])
 
         # Start of the IR/Raman frequency section.
         # Example:
@@ -196,38 +194,38 @@ class MOPAC(logfileparser.Logfile):
         # TRAVEL      0.0359        C 15 --  H 29           +6.0% (802.8%)    24.5%
         # RED. MASS   1.7417        C 13 --  C 17           +5.8% (792.7%)     0.0%
         # EFF. MASS1242.2114
-        if line[1:10] == 'VIBRATION':
+        if line[1:10] == "VIBRATION":
             self.updateprogress(inputfile, "Frequency Information", self.fupdate)
 
             # get the vib symmetry
             if len(line.split()) >= 3:
                 sym = line.split()[2]
-                if not hasattr(self, 'vibsyms'):
+                if not hasattr(self, "vibsyms"):
                     self.vibsyms = []
                 self.vibsyms.append(sym)
 
-            line = inputfile.next()
-            if 'FREQ' in line:
-                if not hasattr(self, 'vibfreqs'):
+            line = next(inputfile)
+            if "FREQ" in line:
+                if not hasattr(self, "vibfreqs"):
                     self.vibfreqs = []
                 freq = float(line.split()[1])
                 self.vibfreqs.append(freq)
 
-            line = inputfile.next()
-            if 'T-DIPOLE' in line:
-                if not hasattr(self, 'vibirs'):
+            line = next(inputfile)
+            if "T-DIPOLE" in line:
+                if not hasattr(self, "vibirs"):
                     self.vibirs = []
                 tdipole = float(line.split()[1])
                 # transform to km/mol
                 self.vibirs.append(math.sqrt(tdipole))
 
-            line = inputfile.next()
-            if 'TRAVEL' in line:
+            line = next(inputfile)
+            if "TRAVEL" in line:
                 pass
 
-            line = inputfile.next()
-            if 'RED. MASS' in line:
-                if not hasattr(self, 'vibrmasses'):
+            line = next(inputfile)
+            if "RED. MASS" in line:
+                if not hasattr(self, "vibrmasses"):
                     self.vibrmasses = []
                 rmass = float(line.split()[2])
                 self.vibrmasses.append(rmass)
@@ -236,15 +234,15 @@ class MOPAC(logfileparser.Logfile):
         #           ALPHA EIGENVALUES
         #            BETA EIGENVALUES
         # or just "EIGENVALUES" for closed-shell
-        if 'EIGENVALUES' in line:
-            if not hasattr(self, 'moenergies'):
-                self.moenergies = [] # list of arrays
+        if "EIGENVALUES" in line:
+            if not hasattr(self, "moenergies"):
+                self.moenergies = []  # list of arrays
 
             energies = []
-            line = inputfile.next()
+            line = next(inputfile)
             while len(line.split()) > 0:
                 energies.extend([float(i) for i in line.split()])
-                line = inputfile.next()
+                line = next(inputfile)
             self.moenergies.append(energies)
 
         # todo:
@@ -252,5 +250,5 @@ class MOPAC(logfileparser.Logfile):
         # Example:
         # NET ATOMIC CHARGES
 
-        if line[:16] == '== MOPAC DONE ==':
-            self.metadata['success'] = True
+        if line[:16] == "== MOPAC DONE ==":
+            self.metadata["success"] = True
