@@ -1,6 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import print_function
+# Copyright (c) 2024, the cclib development team
+#
+# This file is part of cclib (http://cclib.github.io) and is distributed under
+# the terms of the BSD 3-Clause License.
 
 import os
 import sys
@@ -11,6 +12,6 @@ def check_cclib(cclib):
     and should have been updated just before running this script. Note that
     this script does not assume any version in the module and just takes
     what it finds... so an appropriate checkout should be done first."""
-    if cclib.__file__[:len(os.getcwd())] != os.getcwd():
+    if cclib.__file__[: len(os.getcwd())] != os.getcwd():
         print("Do not seem to be importing from current directory")
         sys.exit(1)
