@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -9,10 +7,12 @@
 
 import itertools
 
+from cclib.parser.data import ccData
+
 import numpy
 
 
-def get_minimum_carbon_separation(data):
+def get_minimum_carbon_separation(data: ccData) -> float:
     """Returns minimum carbon distance for any coordinates.
 
     Note that atomcoords is 3D, and we will take the minimum
