@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -9,7 +7,6 @@
 
 import json
 import os
-import unittest
 from math import sqrt
 
 import cclib
@@ -19,7 +16,7 @@ __filepath__ = os.path.realpath(__filedir__)
 __datadir__ = os.path.join(__filepath__, "..", "..")
 
 
-class CJSONTest(unittest.TestCase):
+class CJSONWriterTest:
     """Unit tests for the CJSON writer."""
 
     def test_init(self):
@@ -29,7 +26,7 @@ class CJSONTest(unittest.TestCase):
         cjson = cclib.io.cjsonwriter.CJSON(data)
 
         # The object should keep the ccData instance passed to its constructor.
-        self.assertEqual(cjson.ccdata, data)
+        assert cjson.ccdata == data
 
     def test_cjson_generation(self):
         """Does the CJSON format get generated properly?"""
@@ -40,21 +37,18 @@ class CJSONTest(unittest.TestCase):
 
         # The data available in the cjson and ccdata objects should be equal.
         json_data = json.loads(cjson)
-        number_of_atoms = json_data['properties']['number of atoms']
-        self.assertEqual(number_of_atoms, data.natom)
+        number_of_atoms = json_data["properties"]["number of atoms"]
+        assert number_of_atoms == data.natom
 
-        dipole_moment = json_data['properties']['total dipole moment']
-        self.assertAlmostEqual(
-            dipole_moment,
-            sqrt(sum(data.moments[1] ** 2))
-        )
+        dipole_moment = json_data["properties"]["total dipole moment"]
+        assert round(abs(dipole_moment - sqrt(sum(data.moments[1] ** 2))), 7) == 0
 
         # Ensure the bond connectivity index starts from 0
-        bonds = json_data.get('bonds', None)
-        self.assertIsNotNone(bonds)
-        indices = bonds['connections']['index']
-        self.assertEqual(min(indices), 0)
-        self.assertTrue(max(indices) < number_of_atoms)
+        bonds = json_data.get("bonds", None)
+        assert bonds is not None
+        indices = bonds["connections"]["index"]
+        assert min(indices) == 0
+        assert max(indices) < number_of_atoms
 
     def test_zero_dipole_moment(self):
         """Does the CJSON writer handle zero dipole moment correctly?"""
@@ -64,7 +58,7 @@ class CJSONTest(unittest.TestCase):
         cjson = cclib.io.cjsonwriter.CJSON(data).generate_repr()
 
         json_data = json.loads(cjson)
-        self.assertAlmostEqual(json_data["properties"]['total dipole moment'], 0.0)
+        assert round(abs(json_data["properties"]["total dipole moment"]), 7) == 0
 
     def test_missing_dipole_moment(self):
         """Does the CJSON writer handle missing properties correctly?"""
@@ -75,8 +69,4 @@ class CJSONTest(unittest.TestCase):
         cjson = cclib.io.cjsonwriter.CJSON(data).generate_repr()
 
         json_data = json.loads(cjson)
-        self.assertFalse("total dipole moment" in json_data["properties"])
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert "total dipole moment" not in json_data["properties"]
