@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -8,27 +6,22 @@
 """Unit tests for general file writer."""
 
 import os
-import unittest
 
 import cclib
 
+import pytest
 
 __filedir__ = os.path.dirname(__file__)
 __filepath__ = os.path.realpath(__filedir__)
 __datadir__ = os.path.join(__filepath__, "..", "..")
 
 
-class WriterTest(unittest.TestCase):
-
+class FileWriterTest:
     def test_init(self):
-        """Does the class initialize correctly?"""
+        """Does the class initialize properly?"""
+
+        # You cannot instantiate a class with abstract methods.
         fpath = os.path.join(__datadir__, "data/ADF/basicADF2007.01/dvb_gopt.adfout")
         data = cclib.io.ccread(fpath)
-        writer = cclib.io.filewriter.Writer(data)
-
-        # The object should keep the ccData instance passed to its constructor.
-        self.assertEqual(writer.ccdata, data)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        with pytest.raises(TypeError):
+            cclib.io.filewriter.Writer(data)
