@@ -1,31 +1,25 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2024, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
 
 """Test the MBO method in cclib"""
 
-from __future__ import print_function
-
-import sys
-import os
 import logging
-import unittest
-
-import numpy
+import os
+import sys
 
 from cclib.method import MBO
 from cclib.parser import Gaussian
 
+import numpy
+
 sys.path.insert(1, "..")
 
 from ..test_data import getdatafile
 
 
-class MBOTest(unittest.TestCase):
-
+class MBOTest:
     def test_mbo_sp(self):
         """Testing Mayer bond orders for restricted single point."""
 
@@ -34,9 +28,9 @@ class MBOTest(unittest.TestCase):
         mbo.logger.setLevel(logging.ERROR)
         mbo.calculate()
 
-        e_mbo = numpy.loadtxt(os.path.dirname(os.path.realpath(__file__)) + "/dvb_sp.mbo")
-        self.assertTrue(numpy.all(mbo.fragresults[0] >= e_mbo - 0.25))
-        self.assertTrue(numpy.all(mbo.fragresults[0] <= e_mbo + 0.25))
+        e_mbo = numpy.loadtxt(f"{os.path.dirname(os.path.realpath(__file__))}/dvb_sp.mbo")
+        assert numpy.all(mbo.fragresults[0] >= e_mbo - 0.25)
+        assert numpy.all(mbo.fragresults[0] <= e_mbo + 0.25)
 
     def test_mbo_un_sp(self):
         """Testing Mayer bond orders for unrestricted single point."""
@@ -46,10 +40,7 @@ class MBOTest(unittest.TestCase):
         mbo.logger.setLevel(logging.ERROR)
         mbo.calculate()
 
-        e_mbo = numpy.loadtxt(os.path.dirname(os.path.realpath(__file__)) + "/dvb_un_sp.mbo")
+        e_mbo = numpy.loadtxt(f"{os.path.dirname(os.path.realpath(__file__))}/dvb_un_sp.mbo")
         bond_orders = mbo.fragresults[0] + mbo.fragresults[1]
-        self.assertTrue(numpy.all(bond_orders >= e_mbo - 0.30))
-        self.assertTrue(numpy.all(bond_orders <= e_mbo + 0.30))
-
-if __name__ == "__main__":
-    unittest.TextTestRunner(verbosity=2).run(unittest.makeSuite(MBOTest))
+        assert numpy.all(bond_orders >= e_mbo - 0.30)
+        assert numpy.all(bond_orders <= e_mbo + 0.30)
